## cdist-type__install_umount(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__install_umount - umount target directory

## 2. DESCRIPTION

This cdist type allows you to recursively umount the given target directory.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

target
  the mount point to umount. Defaults to object_id

## 5. EXAMPLES

    __install_umount /target

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).